package com.beone.java.eclipsemagazinexamples;

import net.sourceforge.nattable.NatTable;
import net.sourceforge.nattable.config.ConfigRegistry;
import net.sourceforge.nattable.data.ListDataProvider;

import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;

import com.beone.java.eclipsemagazinexamples.data.PersonService;
import com.beone.java.eclipsemagazinexamples.data.PersonWithAddress;
import com.beone.java.eclipsemagazinexamples.data.PersonWithAddressColumnPropertyAccessor;
import com.beone.java.eclipsemagazinexamples.layer.CustomDataGridLayer;

/**
 * Example that opens a window that shows a NatTable that contains several complex objects of
 * type {@link PersonWithAddress}.
 * It uses the customized {@link CustomDataGridLayer} for the {@link NatTable} which uses a customized
 * {@link PersonWithAddressColumnPropertyAccessor} to access the data within a {@link ListDataProvider} within
 * the body region. 
 * As we still use the default implementations of the layers themself by only customizing the 
 * data access, we still "only" support selection, scrolling, resizing and reordering.
 * 
 * @author Dirk Huler
 */
public class CustomDataNatTableExample {

	/**
	 * Opens a new window and shows a grid build with {@link CustomDataNatTableExample#createControl(Composite)}
	 * @param args
	 */
	public static void main(String[] args) {
		final Display display = Display.getDefault();
		final Shell shell = new Shell(display, SWT.SHELL_TRIM);
		shell.setLayout(new FillLayout());
		shell.setSize(800, 600);
		shell.setText("Custom data NatTable example");

		createControl(shell);
		
		shell.open();
		
		while (!shell.isDisposed()) {
			if (!display.readAndDispatch()) {
				display.sleep();
			}
		}

		shell.dispose();
		display.dispose();
	}

	/**
	 * Creates a simple {@link NatTable} with {@link CustomDataGridLayer} that shows 
	 * {@link PersonWithAddress} objects.
	 * @param parent
	 * @return
	 */
	public static Control createControl(Composite parent) {
		//create a new ConfigRegistry which will be needed for GlazedLists handling
		ConfigRegistry configRegistry = new ConfigRegistry();
		//create NatTable with autoconfigure off because we want to add our created configRegistry
		CustomDataGridLayer grid = 
			new CustomDataGridLayer(PersonService.getPersonsWithAddress(10), configRegistry);
		NatTable natTable = new NatTable(parent, grid);
		return natTable;
	}

}
