package net.sourceforge.nattable.extension.glazedlists;

import java.util.Comparator;

import net.sourceforge.nattable.config.IConfigRegistry;
import net.sourceforge.nattable.config.NullComparator;
import net.sourceforge.nattable.data.IColumnAccessor;
import net.sourceforge.nattable.data.IColumnPropertyAccessor;
import net.sourceforge.nattable.data.IColumnPropertyResolver;
import net.sourceforge.nattable.layer.ILayer;
import net.sourceforge.nattable.layer.cell.LayerCell;
import net.sourceforge.nattable.sort.SortConfigAttributes;
import ca.odell.glazedlists.gui.AdvancedTableFormat;

public class NatColumnTableFormat<R> implements AdvancedTableFormat<R> {

	private final IColumnPropertyResolver columnPropertyResolver;
	private IColumnAccessor<R> columnAccessor;
	private IConfigRegistry configRegistry;
	private final ILayer columnHeaderDataLayer;
	
	public NatColumnTableFormat(IColumnPropertyAccessor<R> columnPropertyAccessor, IConfigRegistry configRegistry, ILayer dataLayer) {
		this(columnPropertyAccessor, columnPropertyAccessor, configRegistry, dataLayer);
	}
	
	public NatColumnTableFormat(IColumnAccessor<R> columnAccessor, IColumnPropertyResolver columnPropertyResolver, IConfigRegistry configRegistry, ILayer columnHeaderDataLayer) {
		this.columnPropertyResolver = columnPropertyResolver;
		this.columnAccessor = columnAccessor;
		this.configRegistry = configRegistry;
		this.columnHeaderDataLayer = columnHeaderDataLayer;
	}

	public Class<?> getColumnClass(int col) {
		return null;
	}

	public Comparator<?> getColumnComparator(final int col) {
		LayerCell cell = columnHeaderDataLayer.getCellByPosition(col, 0);
		Comparator<?> comparator = configRegistry.getConfigAttribute(
										SortConfigAttributes.SORT_COMPARATOR,
										cell.getDisplayMode(),
										cell.getConfigLabels().getLabels());
		
		return (comparator instanceof NullComparator) ? null : comparator;
	}

	public String getColumnName(int col) {
		return columnPropertyResolver.getColumnProperty(col);
	}

	public int getColumnCount() {
		return columnAccessor.getColumnCount();
	}

	public Object getColumnValue(R rowObj, int col) {
		return columnAccessor.getDataValue(rowObj, col);
	}
	
}
