package net.sourceforge.nattable.group;

import java.util.Collection;
import java.util.HashSet;

import net.sourceforge.nattable.group.command.RowGroupExpandCollapseCommandHandler;
import net.sourceforge.nattable.hideshow.AbstractRowHideShowLayer;
import net.sourceforge.nattable.layer.IUniqueIndexLayer;
import net.sourceforge.nattable.selection.SelectRowGroupCommandHandler;
import net.sourceforge.nattable.selection.SelectionLayer;

public class RowGroupExpandCollapseLayer extends AbstractRowHideShowLayer implements IRowGroupModelListener {

	private final RowGroupModel model;
	
	public RowGroupExpandCollapseLayer(IUniqueIndexLayer underlyingLayer, SelectionLayer selectionLayer, RowGroupModel model) {
		super(underlyingLayer);
		this.model = model;

		model.registerRowGroupModelListener(this);

		registerCommandHandler(new RowGroupExpandCollapseCommandHandler(this));
		registerCommandHandler(new SelectRowGroupCommandHandler(this, selectionLayer));
	}
	
	public RowGroupModel getModel() {
		return model;
	}
	
	// Expand/collapse

	@Override
	public boolean isRowIndexHidden(int rowIndex) {
		
		IUniqueIndexLayer underlyingLayer = (IUniqueIndexLayer) getUnderlyingLayer();
		
		boolean isHiddeninUnderlyingLayer = 
			RowGroupUtils.isRowIndexHiddenInUnderLyingLayer(rowIndex, this, underlyingLayer);
		boolean isCollapsedAndStaticRow = model.isCollapsed(rowIndex) &&
			!RowGroupUtils.isStaticOrFirstVisibleRow(rowIndex, underlyingLayer, underlyingLayer, model);
		
		return isHiddeninUnderlyingLayer || isCollapsedAndStaticRow;
	}
	
	@Override
	public Collection<Integer> getHiddenRowIndexes() {
		Collection<Integer> hiddenRowIndexes = new HashSet<Integer>();

		IUniqueIndexLayer underlyingLayer = (IUniqueIndexLayer) getUnderlyingLayer();
		int underlyingColumnCount = underlyingLayer.getRowCount();
		for (int i = 0; i < underlyingColumnCount; i++) {
			int rowIndex = underlyingLayer.getRowIndexByPosition(i);

			if (model.isCollapsed(rowIndex)) {
				if (!RowGroupUtils.isStaticOrFirstVisibleRow(rowIndex, underlyingLayer, underlyingLayer, model)) {
					hiddenRowIndexes.add(Integer.valueOf(rowIndex));
				}
			}
		}

		return hiddenRowIndexes;
	}

	// IRowGroupModelListener
	
	public void rowGroupModelChanged() {
		invalidateCache();
	}

}
