package net.sourceforge.nattable.tree.config;

import net.sourceforge.nattable.config.IConfigRegistry;
import net.sourceforge.nattable.layer.cell.LayerCell;
import net.sourceforge.nattable.painter.cell.BackgroundPainter;
import net.sourceforge.nattable.painter.cell.CellPainterWrapper;
import net.sourceforge.nattable.painter.cell.decorator.CellPainterDecorator;
import net.sourceforge.nattable.tree.ITreeRowModel;
import net.sourceforge.nattable.ui.util.CellEdgeEnum;

import org.eclipse.swt.graphics.GC;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.graphics.Rectangle;


public class DefaultTreeCellPainter extends CellPainterWrapper {

	private final ITreeRowModel<?> treeRowModel;
	private final int treeIndent;
	private final BackgroundPainter treeBackgroundPainter;
	
	public DefaultTreeCellPainter(ITreeRowModel<?> treeRowModel, int treeIndent, Image plusImage, Image minusImage, Image leafImage) {
		this.treeRowModel = treeRowModel;
		this.treeIndent = treeIndent;
		this.treeBackgroundPainter = new BackgroundPainter();
		
		setWrappedPainter(new CellPainterDecorator(new DefaultTreeTextPainter(treeRowModel), CellEdgeEnum.LEFT, new DefaultTreeImagePainter(treeRowModel, plusImage, minusImage, leafImage)));
	}

	@Override
	public void paintCell(LayerCell cell, GC gc, Rectangle bounds, IConfigRegistry configRegistry) {
		this.treeBackgroundPainter.paintCell(cell, gc, bounds, configRegistry);
		
		int index = cell.getLayer().getRowIndexByPosition(cell.getRowPosition());
		int depth = this.treeRowModel.depth(index);
		if( depth > 0 ) {
			bounds.x = getIndent(bounds.x, depth);
			bounds.width = bounds.width - getIndent(depth);
		}
		
		super.paintCell(cell, gc, bounds, configRegistry);
	}
	
	protected int getIndent() {
		return this.treeIndent;
	}
	
	protected int getIndent(int depth) {
		return getIndent() * depth;
	}
	
	protected int getIndent(int x, int depth) {
		return x + getIndent(depth);
	}
}
