package net.sourceforge.nattable.tree.config;

import net.sourceforge.nattable.NatTable;
import net.sourceforge.nattable.layer.LabelStack;
import net.sourceforge.nattable.layer.cell.LayerCell;
import net.sourceforge.nattable.tree.ITreeRowModel;
import net.sourceforge.nattable.tree.TreeLayer;
import net.sourceforge.nattable.ui.NatEventData;
import net.sourceforge.nattable.ui.matcher.MouseEventMatcher;

import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.graphics.Rectangle;


public class DefaultTreeMouseEventMatcher extends MouseEventMatcher {
	
	private final ITreeRowModel<?> treeRowModel;
	private final int treeIndent;
	private final Rectangle plusImageBounds;
	private final Rectangle minusImageBounds;
	
	public DefaultTreeMouseEventMatcher(ITreeRowModel<?> treeRowModel, int treeIndent, Rectangle plusImageBounds, Rectangle minusImageBounds) {
		super(TreeLayer.TREE_COLUMN_CELL, LEFT_BUTTON);
		this.treeRowModel = treeRowModel;
		this.treeIndent = treeIndent;
		this.plusImageBounds = plusImageBounds;
		this.minusImageBounds = minusImageBounds;
	}
	
	@Override
	public boolean matches(NatTable natTable, MouseEvent event, LabelStack regionLabels) {
		if(super.matches(natTable, event, regionLabels)){
							
			NatEventData eventData = NatEventData.createInstanceFromEvent(event);
			LayerCell cell = natTable.getCellByPosition(eventData.getColumnPosition(), eventData.getRowPosition());
						
			int index = natTable.getRowIndexByPosition(eventData.getRowPosition());
			int depth = this.treeRowModel.depth(index);
			boolean collapsed = this.treeRowModel.isCollapsed(index);
			
			final Rectangle rectangle = new Rectangle( getIndent(cell.getBounds().x, depth), cell.getBounds().y, getWidth(collapsed), cell.getBounds().height );
			if( rectangle.contains( event.x, event.y ) ) {
				return true;
			}

		}
		return false;
	}
	
	protected int getIndent() {
		return this.treeIndent;
	}
	
	protected int getIndent(int depth) {
		return getIndent() * depth;
	}
	
	protected int getIndent(int x, int depth) {
		return x + getIndent(depth);
	}
	
	protected int getWidth(boolean collapsed) {
		return collapsed ? this.minusImageBounds.width : this.plusImageBounds.width;
	}
}
