package net.sourceforge.nattable.ui.menu;

import net.sourceforge.nattable.NatTable;
import net.sourceforge.nattable.config.AbstractUiBindingConfiguration;
import net.sourceforge.nattable.grid.GridRegion;
import net.sourceforge.nattable.ui.binding.UiBindingRegistry;
import net.sourceforge.nattable.ui.matcher.MouseEventMatcher;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.DisposeEvent;
import org.eclipse.swt.events.DisposeListener;
import org.eclipse.swt.widgets.Menu;

public class HeaderMenuConfiguration extends AbstractUiBindingConfiguration {

	private Menu colHeaderMenu;
	private Menu rowHeaderMenu;
	public enum MenuOptions {HideColumn, ShowColumn};

	public HeaderMenuConfiguration(NatTable natTable) {
		colHeaderMenu = createColumnHeaderMenu(natTable).build();
		rowHeaderMenu = createRowHeaderMenu(natTable).build();

		natTable.addDisposeListener(new DisposeListener() {

			public void widgetDisposed(DisposeEvent e) {
				colHeaderMenu.dispose();
				rowHeaderMenu.dispose();
			}

		});
	}

	protected PopupMenuBuilder createColumnHeaderMenu(NatTable natTable) {
		return new PopupMenuBuilder(natTable)
								.withHideColumnMenuItem()
								.withShowAllColumnsMenuItem()
								.withCreateColumnGroupsMenuItem()
								.withUngroupColumnsMenuItem()
								.withAutoResizeSelectedColumnsMenuItem()
								.withColumnStyleEditor("Edit styles")
								.withColumnRenameDialog("Rename column")
								.withClearAllFilters("Clear all filters");
	}

	protected PopupMenuBuilder createRowHeaderMenu(NatTable natTable) {
		return new PopupMenuBuilder(natTable)
								.withAutoResizeSelectedRowsMenuItem();
	}

	public void configureUiBindings(UiBindingRegistry uiBindingRegistry) {
		uiBindingRegistry.registerMouseDownBinding(
				new MouseEventMatcher(SWT.NONE, GridRegion.COLUMN_HEADER, MouseEventMatcher.RIGHT_BUTTON),
				new PopupMenuAction(colHeaderMenu));

		uiBindingRegistry.registerMouseDownBinding(
				new MouseEventMatcher(SWT.NONE, GridRegion.ROW_HEADER, MouseEventMatcher.RIGHT_BUTTON),
				new PopupMenuAction(rowHeaderMenu));
	}

}
